@@ -15,7 +15,7 @@ Dancer2::Plugin::Database - easy database connections for Dancer2 applications
 
 =cut
 
-our $VERSION = '2.12';
+our $VERSION = '2.14';
 
 register_hook qw(database_connected
                  database_connection_lost
@@ -23,13 +23,12 @@ register_hook qw(database_connected
                  database_error);
 
 
-my $settings = undef;
+my $settings = {};
 
-
-sub _load_db_settings {
-    my $self = shift;
+sub _load_settings {
+    my $dsl = shift;
     $settings = plugin_setting();
-    $settings->{charset} ||= $self->setting('charset');
+    $settings->{charset} ||= $dsl->setting('charset') || 'utf-8';
 }
 
 register database => sub {
@@ -42,10 +41,20 @@ register database => sub {
     # wasn't working properly calling the Dancer2::Plugin execute_hook
     # directly
     my $hook_exec = sub {
-        $dsl->execute_hook(@_);
+        if ( $dsl->can('execute_plugin_hook') ) {
+            # Plugin2
+            $dsl->execute_plugin_hook(@_);
+        }
+        else {
+            # old behaviour
+            $dsl->execute_hook(@_);
+        }
     };
 
-    _load_db_settings($dsl) unless $settings;
+    ## This is mostly for the case the user uses 'set plugins' and
+    ## changes configuration during runtime. For example in our test suite.
+    _load_settings($dsl);
+
     my ($dbh, $cfg) = Dancer::Plugin::Database::Core::database( arg => $_[0],
                                                                 logger => $logger,
                                                                 hook_exec => $hook_exec,
